@@ -553,6 +553,16 @@ BOOST_AUTO_TEST_CASE(issue_161_test) {
   BOOST_CHECK_EQUAL(queries["param1"], "-");
   BOOST_CHECK_EQUAL(queries["param2"], "some+plus+encoded+text");
   BOOST_CHECK_EQUAL(queries["param3"], "~");
-  BOOST_CHECK_EQUAL(uri::decoded(queries["param2"]),
-                    "some plus encoded text");
+  BOOST_CHECK_EQUAL(uri::decoded(queries["param2"]), "some plus encoded text");
+}
+
+BOOST_AUTO_TEST_CASE(issue_364_test) {
+  uri::uri instance;
+  uri::schemes::http(instance) << uri::host("my.awesome.server.com");
+  BOOST_CHECK_EQUAL("my.awesome.server.com", uri::authority(instance));
+}
+
+BOOST_AUTO_TEST_CASE(issue_447_test) {
+  uri::uri instance("http://[www.foo.com/");
+  BOOST_REQUIRE(!uri::valid(instance));
 }
